==> ShopMadeSimple0.1.2.zip: ShopMadeSimple/method.uninstall.php <==
<?php
if (!isset($gCms)) exit;
/**
 * Destroy all tables
 */
$this->categories->DestroyTables();
$this->products->DestroyTables();
#$this->translations->DestroyTables();
/**
 * Destroy all preferences
 */
$this->RemovePreference('admin_name');
$this->RemovePreference('admin_email');
$this->RemovePreference('shop_name');
$this->RemovePreference('shop_phone');
$this->RemovePreference('shop_online');
$this->RemovePreference('default_language');
$this->RemovePreference('pricesinclvat');
$this->RemovePreference('weightunitmeasure');
$this->RemovePreference('default_currency');
$this->RemovePreference('default_symbol');
$this->RemovePreference('imagepath_category');
$this->RemovePreference('imagepath_product');
/**
 * Destroy security permissions
 */
$this->RemovePermission('Use ShopMadeSimple', 'Use ShopMadeSimple');
$this->RemovePermission('Edit Preferences', 'Edit Preferences');
$this->RemovePermission('Add/Delete Category', 'Add/Delete Category');
$this->RemovePermission('Edit Category', 'Edit Category');
$this->RemovePermission('Add/Delete Products', 'Add/Delete Products');
$this->RemovePermission('Edit Products', 'Edit Products');
$this->RemovePermission('Add/Delete Translations', 'Add/Delete Translations');
$this->RemovePermission('Edit Translations', 'Edit Translations');
$this->RemovePermission('Add/Delete Templates', 'Add/Delete Templates');
$this->RemovePermission('Edit Templates', 'Edit Templates');

$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled',$this->GetVersion()));
?>

==> ShopMadeSimple0.1.3.zip: ShopMadeSimple/method.uninstall.php <==
<?php
if (!isset($gCms)) exit;
/**
 * Destroy all tables
 */
$this->categories->DestroyTables();
$this->products->DestroyTables();
#$this->translations->DestroyTables();
/**
 * Destroy all preferences
 */
$this->RemovePreference('admin_name');
$this->RemovePreference('admin_email');
$this->RemovePreference('shop_name');
$this->RemovePreference('shop_phone');
$this->RemovePreference('shop_online');
$this->RemovePreference('default_language');
$this->RemovePreference('pricesinclvat');
$this->RemovePreference('weightunitmeasure');
$this->RemovePreference('default_currency');
$this->RemovePreference('default_symbol');
$this->RemovePreference('imagepath_category');
$this->RemovePreference('imagepath_product');
/**
 * Destroy security permissions
 */
$this->RemovePermission('Use ShopMadeSimple', 'Use ShopMadeSimple');
$this->RemovePermission('Edit Preferences', 'Edit Preferences');
$this->RemovePermission('Add/Delete Category', 'Add/Delete Category');
$this->RemovePermission('Edit Category', 'Edit Category');
$this->RemovePermission('Add/Delete Products', 'Add/Delete Products');
$this->RemovePermission('Edit Products', 'Edit Products');
$this->RemovePermission('Add/Delete Translations', 'Add/Delete Translations');
$this->RemovePermission('Edit Translations', 'Edit Translations');
$this->RemovePermission('Add/Delete Templates', 'Add/Delete Templates');
$this->RemovePermission('Edit Templates', 'Edit Templates');

// Remove style sheet that belong to this module
$css_name = $this->Lang('module_example_stylesheet'); // Retrieve the name of the new stylesheet locate in the css directory
$query = 'DELETE FROM '.cms_db_prefix().'css WHERE css_name = ?';
$db->Execute($query, array($css_name));

// Remove templates that belong to this module
$query = 'DELETE FROM '.cms_db_prefix().'module_templates WHERE module_name = ?';
$db->Execute($query, array('ShopMadeSimple'));

$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled',$this->GetVersion()));
?>
